Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2380)

Unified Diff: chrome/browser/history/history_backend.h

Issue 6698031: fav icon -> favicon. Pass 7: FavIconID -> FaviconID (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 9 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/history/history_backend.h
diff --git a/chrome/browser/history/history_backend.h b/chrome/browser/history/history_backend.h
index 21ec9890661cd082375c17095a8f6b048a6a36cc..1012ce19724077d69d7d80d80d0a4e85b3e5a621 100644
--- a/chrome/browser/history/history_backend.h
+++ b/chrome/browser/history/history_backend.h
@@ -457,18 +457,18 @@ class HistoryBackend : public base::RefCountedThreadSafe<HistoryBackend>,
// Sets the favicon url id for page_url to id. This will also broadcast
// notifications as necessary.
void SetFaviconMapping(const GURL& page_url,
- FavIconID id,
+ FaviconID id,
IconType icon_type);
// Updates the FavIconID associated with the url of a page. If there is an
// existing mapping between |page_url| and |id| this does nothing and returns
// false. If the mapping needs to be added or updated, true is returned. If
// there is an existing mapping but it does not map to |id|, then the |id| of
// the replaced FavIconID is set in |replaced_icon_id|.
bool AddOrUpdateIconMapping(const GURL& page_url,
- FavIconID id,
+ FaviconID id,
IconType icon_type,
- FavIconID* replaced_icon_id);
+ FaviconID* replaced_icon_id);
// Generic stuff -------------------------------------------------------------
« no previous file with comments | « chrome/browser/history/expire_history_backend_unittest.cc ('k') | chrome/browser/history/history_backend.cc » ('j') | no next file with comments »
@@ -457,18 +457,18 @@ class HistoryBackend : public base::RefCountedThreadSafe<HistoryBackend>,
IconType icon_type);
- // Updates the FavIconID associated with the url of a page. If there is an
+ // Updates the FaviconID associated with the url of a page. If there is an
// existing mapping between |page_url| and |id| this does nothing and returns
// false. If the mapping needs to be added or updated, true is returned. If
@@ -457,18 +457,18 @@ class HistoryBackend : public base::RefCountedThreadSafe<HistoryBackend>,
// false. If the mapping needs to be added or updated, true is returned. If
// there is an existing mapping but it does not map to |id|, then the |id| of
- // the replaced FavIconID is set in |replaced_icon_id|.
+ // the replaced FaviconID is set in |replaced_icon_id|.
bool AddOrUpdateIconMapping(const GURL& page_url,

Powered by Google App Engine
This is Rietveld 408576698